
Need a linebreak to include comments

Associate with a key - line before or on same line

LAYER
	# name comment
	NAME "Test" # another name comment
END

Allow lists of comments? How to format these?

NAME "Test" # comment 1 comment 2

Associate with an object - put at top of definition?

# Map comment
MAP

END

# My layer
LAYER

END